export enum NodeType {
    ArrayExpression = 'ArrayExpression',
    ArrayPattern = 'ArrayPattern',
    ArrowFunctionExpression = 'ArrowFunctionExpression',
    AssignmentExpression = 'AssignmentExpression',
    AssignmentPattern = 'AssignmentPattern',
    AwaitExpression = 'AwaitExpression',
    BinaryExpression = 'BinaryExpression',
    BlockStatement = 'BlockStatement',
    BreakStatement = 'BreakStatement',
    CallExpression = 'CallExpression',
    CatchClause = 'CatchClause',
    ChainExpression = 'ChainExpression',
    ClassBody = 'ClassBody',
    ClassDeclaration = 'ClassDeclaration',
    ConditionalExpression = 'ConditionalExpression',
    ContinueStatement = 'ContinueStatement',
    DoWhileStatement = 'DoWhileStatement',
    ExportAllDeclaration = 'ExportAllDeclaration',
    ExportNamedDeclaration = 'ExportNamedDeclaration',
    ExportSpecifier = 'ExportSpecifier',
    ExpressionStatement = 'ExpressionStatement',
    ForStatement = 'ForStatement',
    ForInStatement = 'ForInStatement',
    ForOfStatement = 'ForOfStatement',
    FunctionDeclaration = 'FunctionDeclaration',
    FunctionExpression = 'FunctionExpression',
    Identifier = 'Identifier',
    IfStatement = 'IfStatement',
    ImportDeclaration = 'ImportDeclaration',
    ImportDefaultSpecifier = 'ImportDefaultSpecifier',
    ImportNamespaceSpecifier = 'ImportNamespaceSpecifier',
    ImportSpecifier = 'ImportSpecifier',
    LabeledStatement = 'LabeledStatement',
    Literal = 'Literal',
    LogicalExpression = 'LogicalExpression',
    MemberExpression = 'MemberExpression',
    MethodDefinition = 'MethodDefinition',
    NewExpression = 'NewExpression',
    ObjectExpression = 'ObjectExpression',
    ObjectPattern = 'ObjectPattern',
    Program = 'Program',
    Property = 'Property',
    PropertyDefinition = 'PropertyDefinition',
    RestElement = 'RestElement',
    ReturnStatement = 'ReturnStatement',
    SequenceExpression = 'SequenceExpression',
    SpreadElement = 'SpreadElement',
    Super = 'Super',
    SwitchCase = 'SwitchCase',
    SwitchStatement = 'SwitchStatement',
    TaggedTemplateExpression = 'TaggedTemplateExpression',
    TemplateElement = 'TemplateElement',
    TemplateLiteral = 'TemplateLiteral',
    ThisExpression = 'ThisExpression',
    ThrowStatement = 'ThrowStatement',
    TryStatement = 'TryStatement',
    UnaryExpression = 'UnaryExpression',
    UpdateExpression = 'UpdateExpression',
    VariableDeclaration = 'VariableDeclaration',
    VariableDeclarator = 'VariableDeclarator',
    WithStatement = 'WithStatement',
    WhileStatement = 'WhileStatement',
    YieldExpression = 'YieldExpression'
}
